﻿using Aquaforest.ExtendedOCR.Api;
using System;
using System.IO;

namespace ArabicLanguage
{
    class Program
    {
        private static void Main(string[] args)
        {
            try
            {
                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\xbin\resources");

                using (Ocr ocr = new Ocr(resourceFolder))
                {
                    // Set OCR options
                    ocr.EnableConsoleOutput = true;
                    ocr.EnablePdfOutput = true;

                    // Set language to Arabic
                    ocr.Language = SupportedLanguages.Arabic;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;
                    preProcessor.KeepOriginalImage = true;

                    // Read source TIFF file
                    ocr.ReadTIFFSource(@"..\..\..\..\documents\source\arabic.tif");

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(@"..\..\..\..\documents\output\arabic.pdf", true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }
    }
}
