﻿using Aquaforest.ExtendedOCR.Api;
using System;
using System.IO;

namespace AsianLanguages
{
    class Program
    {
        private static void Main(string[] args)
        {
            try
            {
                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\xbin\resources");

                using (Ocr ocr = new Ocr(resourceFolder))
                {
                    // Set OCR options
                    ocr.EnableConsoleOutput = true;
                    ocr.EnablePdfOutput = true;

                    // Set language to the desired Asian language (Japanese, Korean, Tchinese, Schinese)
                    // NOTE: Extended OCR cannot load more than one Asian language at a time.
                    // An Asian language can only be used in conjunction with 'English' and nothing else.
                    ocr.Languages = new SupportedLanguages[]
                    {
                        SupportedLanguages.Korean,
                        SupportedLanguages.English
                    };

                    // Optional: Set the engine to use for Asian languages.
                    // This can be helpful if one engine does not give good OCR results.
                    ocr.AsianOCREngine = AsianOCREngine.OcrAsian1;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;
                    preProcessor.KeepOriginalImage = true;

                    // Read source TIFF file
                    ocr.ReadTIFFSource(@"..\..\..\..\documents\source\korean.tif");

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(@"..\..\..\..\documents\output\korean.pdf", true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }
    }
}
