﻿using System;
using System.IO;
using Aquaforest.OCR.Api;

namespace ConvertBMP_JPEG_PNGToSearchablePDF
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                using (Ocr ocr = new Ocr())
                {
                    string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

                    string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
                    if (!currentEnvironmentVariables.Contains(resourceFolder))
                    {
                        Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                    }

                    // Set OCR options 
                    ocr.ResourceFolder = resourceFolder;
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnablePdfOutput = true;
                    ocr.EnableConsoleOutput = true;
                    
                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;
                    preProcessor.Autorotate = false;

                    // Read source BMP file
                    ocr.ReadBMPSource(@"..\..\..\..\documents\source\BMPSample.bmp");

                    // Read source PNG file
                    //ocr.ReadBMPSource(@"..\..\..\..\documents\source\PNGSample.png");

                    // Read source JPEG file
                    //ocr.ReadBMPSource(@"..\..\..\..\documents\source\JPEGSample.jpg");

                    // OCR the image
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(@"..\..\..\..\documents\output\output.pdf", true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }
    }
}
