﻿using Aquaforest.ExtendedOCR.Api;
using System;
using System.IO;

namespace ConvertTIFFToSearchablePDF
{
    internal class Program
    {
        private static void Main(string[] args)
        {
            try
            {
                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\xbin\resources");

                using (Ocr ocr = new Ocr(resourceFolder))
                {
                    // Set OCR options
                    ocr.EnableConsoleOutput = true;
                    ocr.EnableDebugOutput = false;
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnablePdfOutput = true;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Autorotate = true;
                    preProcessor.Deskew = true;
                    preProcessor.KeepOriginalImage = true;

                    // Read source TIFF file
                    ocr.ReadTIFFSource(Path.GetFullPath(@"..\..\..\..\documents\source\sample.tif"));

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(Path.GetFullPath(@"..\..\..\..\documents\output\sample.pdf"), true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }
    }
}