﻿using Aquaforest.ExtendedOCR.Api;
using Aquaforest.ExtendedOCR.Shared;
using System;
using System.IO;

namespace DetermineWordCoordinates
{
    internal class Program
    {
        private static Ocr ocr;

        private static void Main(string[] args)
        {
            try
            {
                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\xbin\resources");

                // Set OCR options
                ocr = new Ocr(resourceFolder);
                ocr.EnableConsoleOutput = true;
                ocr.EnableDebugOutput = true;
                ocr.Language = SupportedLanguages.English;
                ocr.StatusUpdate += OcrStatusUpdate;

                // Set PreProcessor options
                PreProcessor preProcessor = new PreProcessor();
                preProcessor.Deskew = true;
                preProcessor.Autorotate = false;

                // Read source TIFF file
                ocr.ReadTIFFSource(Path.GetFullPath(@"..\..\..\..\documents\source\sample.tif"));

                // Perform OCR recognition
                ocr.Recognize(preProcessor);

                ocr.DeleteTemporaryFiles();
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
            finally
            {
                if (ocr != null) ocr.Dispose();
            }
        }

        private static void OcrStatusUpdate(object sender, StatusUpdateEventArgs pageCompletedEventArgs)
        {
            Console.WriteLine("Page {0}:", pageCompletedEventArgs.PageNumber);

            Words words = ocr.ReadPageWords(pageCompletedEventArgs.PageNumber);

            foreach (WordData w in words)
            {
                Console.WriteLine("{0} [{1}, {2}]", w.Word, w.Left, w.Bottom);
            }
        }
    }
}