﻿using System;
using System.IO;
using Aquaforest.OCR.Api;
using Aquaforest.OCR.Definitions;

namespace DetermineWordCoordinates
{
    class Program
    {
        static Ocr ocr;

        static void Main(string[] args)
        {
            try
            {
                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

                string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
                if (!currentEnvironmentVariables.Contains(resourceFolder))
                {
                    Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                }

                // Set OCR options 
                ocr = new Ocr();
                ocr.ResourceFolder = resourceFolder;
                ocr.EnableConsoleOutput = true;
                ocr.Language = SupportedLanguages.English;
                ocr.StatusUpdate += new Ocr.StatusUpdateEventHandler(OcrStatusUpdate);

                // Set PreProcessor options
                PreProcessor preProcessor = new PreProcessor();
                preProcessor.Deskew = true;
                preProcessor.Autorotate = false;

                // Read source TIFF file
                ocr.ReadTIFFSource(Path.GetFullPath(@"..\..\..\..\documents\source\sample.tif"));

                // Perform OCR recognition
                ocr.Recognize(preProcessor);

                ocr.DeleteTemporaryFiles();
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
            finally
            {
                if (ocr != null) ocr.Dispose();
            }
        }

        static void OcrStatusUpdate(object sender, StatusUpdateEventArgs pageCompletedEventArgs)
        {
            Console.WriteLine("Page {0}:", pageCompletedEventArgs.PageNumber);

            Words words = ocr.ReadPageWords(pageCompletedEventArgs.PageNumber);

            foreach (WordData w in words)
            {
                Console.WriteLine("{0} [{1}, {2}]", w.Word, w.Left, w.Bottom);
            }
        }
    }
}
