﻿using System;
using System.ComponentModel;
using System.Drawing;
using System.IO;
using System.Text.RegularExpressions;
using System.Windows.Forms;
using Aquaforest.OCR.Api;
using Aquaforest.OCR.Definitions;

namespace Zonal_OCR
{
    public partial class Form1 : Form
    {
        internal class PageResult
        {
            internal int recognisedPageNumber;
            internal TextBox textBox;

            internal PageResult(int page, TextBox textBox)
            {
                recognisedPageNumber = page;
                this.textBox = textBox;
            }
        }

        private Ocr ocr = new Ocr();
        private PreProcessor preProcessor = new PreProcessor();
        private int pageCompleted;
        private BackgroundWorker ocrProcessingBackgroundWorker;
        private bool textAvailable;
        private bool imageAvailable;
        private string textBox1Text;
        private string textBox2Text;
        private string textBox3Text;
        private string textBox4Text;
        private string textBox5Text;
        private string textBox6Text;
        private string textBox7Text;
        private string textBox8Text;
        private string textBox9Text;
        private string textBox10Text;

        private string license = "";

        public Form1()
        {
            try
            {
                InitializeComponent();
                GetLanguageNames();
                comboBoxDespeckle.SelectedIndex = 0;
                ocr.License = license;
                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");
                string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
                if (!currentEnvironmentVariables.Contains(resourceFolder))
                {
                    Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                }
                ocr.ResourceFolder = resourceFolder;
                string version = ocr.Version;
            }
            catch (Exception e)
            {
                MessageBox.Show(e.Message, "Aquaforest");
            }
        }

        private void GetLanguageNames()
        {
            foreach (string language in Enum.GetNames(typeof(SupportedLanguages)))
            {
                comboLanguages.Items.Add(language.Replace('_', ' '));
            }

            comboLanguages.SelectedIndex = 0;
        }

        private void buttonSource_Click(object sender, EventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            openFileDialog.Filter = "PDF|*.pdf|TIFF|*.tif";
            openFileDialog.ShowDialog();
            if (File.Exists(openFileDialog.FileName))
            {
                textBoxSource.Text = openFileDialog.FileName;
                if (Path.GetExtension(openFileDialog.FileName).ToLower() == ".pdf")
                {
                    ocr.ReadPDFSource(openFileDialog.FileName);
                }
                else
                {
                    ocr.ReadTIFFSource(openFileDialog.FileName);
                }

                Color color = Color.Black;
                SetTextBoxColors(color);
            }
        }

        private void SetTextBoxColors(Color color)
        {
            textBox1.ForeColor = color;
            textBox2.ForeColor = color;
            textBox3.ForeColor = color;
            textBox4.ForeColor = color;
            textBox5.ForeColor = color;
            textBox6.ForeColor = color;
            textBox7.ForeColor = color;
            textBox8.ForeColor = color;
            textBox9.ForeColor = color;
            textBox10.ForeColor = color;
        }

        private void EnableUI(bool enable)
        {
            textBoxSource.Enabled = enable;
            buttonOcr.Enabled = enable;
            buttonSource.Enabled = enable;
            comboLanguages.Enabled = enable;
            comboBoxDespeckle.Enabled = enable;
            checkBoxTables.Enabled = enable;
            checkBoxNoPictures.Enabled = enable;
            checkBoxDeskew.Enabled = enable;
            checkBoxAutorotate.Enabled = enable;
            if (!enable)
            {
                SetTextBoxColors(Color.Red);
            }
        }

        private SupportedLanguages GetLanguageValueFromSelectedIndex()
        {
            Array languageses = Enum.GetValues(typeof(SupportedLanguages));
            SupportedLanguages language = (SupportedLanguages)languageses.GetValue(comboLanguages.SelectedIndex);
            return language;
        }

        private void RunOcrOnBackgroundWorker()
        {
            ocrProcessingBackgroundWorker = new BackgroundWorker();
            ocrProcessingBackgroundWorker.DoWork += DoWork;
            ocrProcessingBackgroundWorker.RunWorkerCompleted += OnOcrCompleted;
            ocrProcessingBackgroundWorker.WorkerReportsProgress = true;
            ocrProcessingBackgroundWorker.ProgressChanged += OnOcrProgressChanged;
            ocrProcessingBackgroundWorker.WorkerSupportsCancellation = true;
            ocrProcessingBackgroundWorker.RunWorkerAsync();
        }

        private void ConfigureOcrProcessor()
        {
            ocr.Language = GetLanguageValueFromSelectedIndex();
            preProcessor.Autorotate = checkBoxAutorotate.Checked;
            preProcessor.Deskew = checkBoxDeskew.Checked;
            preProcessor.Despeckle = comboBoxDespeckle.SelectedIndex;
            preProcessor.NoPictures = checkBoxNoPictures.Checked;
            preProcessor.Tables = checkBoxTables.Checked;
            preProcessor.RemoveLines = checkBoxRemoveLines.Checked;
        }

        private void OnOcrCompleted(object sender, RunWorkerCompletedEventArgs runWorkerCompletedEventArgs)
        {
            EnableUI(true);
        }

        private void OcrStatusUpdate(object sender, StatusUpdateEventArgs statusUpdateEventArgs)
        {
            pageCompleted = statusUpdateEventArgs.PageNumber;
            textAvailable = statusUpdateEventArgs.TextAvailable;
            imageAvailable = statusUpdateEventArgs.ImageAvailable;
            if (imageAvailable && textAvailable)
            {
                Rectangle region;
                using (Image image = ocr.GetPageImage(statusUpdateEventArgs.PageNumber))
                {
                    region = GetRegion(image);
                }

                TextBox recognisedPage = CheckRegionalText(statusUpdateEventArgs.PageNumber, region);
                PageResult pageResult = new PageResult(statusUpdateEventArgs.PageNumber, recognisedPage);
                ocrProcessingBackgroundWorker.ReportProgress(0, pageResult);
            }
        }

        private void OnOcrProgressChanged(object sender, ProgressChangedEventArgs progressChangedEventArgs)
        {
            if (progressChangedEventArgs.ProgressPercentage != -1)
            {
                PageResult pageResult = (PageResult) progressChangedEventArgs.UserState;
                pageResult.textBox.ForeColor = Color.Green;
            }
        }

        private void DoWork(object sender, DoWorkEventArgs doWorkEventArgs)
        {
            ocr.StatusUpdate += OcrStatusUpdate;
            ocr.Recognize(preProcessor);
        }

        private void buttonOcr_Click(object sender, EventArgs e)
        {
            preProcessor.Binarize = 200;
            ocr.EnablePdfOutput = true;
            ocr.EnableTextOutput = true;
            ConfigureOcrProcessor();
            GetComparisonText();
            if (File.Exists(textBoxSource.Text))
            {
                EnableUI(false);
                RunOcrOnBackgroundWorker();
            }
        }

        private Rectangle GetRegion(Image image)
        {
            Rectangle region = new Rectangle();
            region.X = 0;
            region.Y = 0;
            region.Width = image.Width;
            region.Height = image.Height/4;

            return region;
        }

        private void Form1_Paint(object sender, PaintEventArgs e)
        {
        }

        private TextBox CheckRegionalText(int page, Rectangle region)
        {
            string recognisedText = ocr.ReadPageString(page, region);         
            return TextBoxNumber(Regex.Replace(recognisedText, @"\s", ""));
        }

        private void GetComparisonText()
        {
            textBox1Text = Regex.Replace(textBox1.Text, @"\s", "");
            textBox2Text = Regex.Replace(textBox2.Text, @"\s", "");
            textBox3Text = Regex.Replace(textBox3.Text, @"\s", "");
            textBox4Text = Regex.Replace(textBox4.Text, @"\s", "");
            textBox5Text = Regex.Replace(textBox5.Text, @"\s", "");
            textBox6Text = Regex.Replace(textBox6.Text, @"\s", "");
            textBox7Text = Regex.Replace(textBox7.Text, @"\s", "");
            textBox8Text = Regex.Replace(textBox8.Text, @"\s", "");
            textBox9Text = Regex.Replace(textBox9.Text, @"\s", "");
            textBox10Text = Regex.Replace(textBox10.Text, @"\s", "");
        }

        private TextBox TextBoxNumber(string text)
        {
            TextBox textBox = null;
            if(text.Contains(textBox1Text))
            {
                textBox = textBox1;
            }
            else if (text.Contains(textBox2Text))
            {
                textBox = textBox2;
            }
            else if (text.Contains(textBox3Text))
            {
                textBox = textBox3;
            }
            else if (text.Contains(textBox4Text))
            {
                textBox = textBox4;
            }
            else if (text.Contains(textBox5Text))
            {
                textBox = textBox5;
            }
            else if (text.Contains(textBox6Text))
            {
                textBox = textBox6;
            }
            else if (text.Contains(textBox7Text))
            {
                textBox = textBox7;
            }
            else if (text.Contains(textBox8Text))
            {
                textBox = textBox8;
            }
            else if (text.Contains(textBox9Text))
            {
                textBox = textBox9;
            }
            else if (text.Contains(textBox10Text))
            {
                textBox = textBox10;
            }

            return textBox;
        }
         
        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            try
            {
                ocr.DeleteTemporaryFiles();
            }
            catch
            {
            }
        }
    }
}
