﻿using System;
using System.IO;
using System.Linq;
using Aquaforest.BarcodeReader.Api;
using Aquaforest.BarcodeReader.Common;

namespace GetMultipleBarcodesPerPage
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                BarcodeReaderSettings settings = new BarcodeReaderSettings();
                settings.ReadMultipleBarcodes = true; //read multiple barcodes per page

                // Barcode formats to look for
                settings.BarcodeFormats[BarcodeFormat.CODE_39] = true;
                settings.BarcodeFormats[BarcodeFormat.CODE_128] = true;
                settings.BarcodeFormats[BarcodeFormat.CODE_93] = true;
                settings.BarcodeFormats[BarcodeFormat.ITF] = true;
                settings.BarcodeFormats[BarcodeFormat.QR_CODE] = true;

                BarcodeReader reader = new BarcodeReader(settings);

                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

                string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
                if (!currentEnvironmentVariables.Contains(resourceFolder))
                {
                    Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                }
                reader.ResourceFolder = resourceFolder;

                reader.DecodeImage(Path.GetFullPath(@"..\..\..\..\documents\source\sample-barcodes.tif"));

                Console.WriteLine();
                Console.WriteLine("Decode Results");
                Console.WriteLine(new string('-', 30));

                foreach (var result in reader.DecodeResults.Where(r => r.Value.Success))
                {
                    var pageResults = result.Value.BarcodeResults;
                    Console.WriteLine("Found {0} barcode{1} on page {2}" + Environment.NewLine, pageResults.Count, pageResults.Count > 1 ? "s" : "", result.Key);

                    foreach (var r in pageResults)
                    {
                        Console.WriteLine("Barcode Format: {0}", r.BarcodeFormat.ToString());
                        Console.WriteLine("Text: {0}", r.Text);
                        Console.WriteLine("Type: {0}", r.Type.ToString());
                        Console.WriteLine();
                    }
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            }
        }
    }
}
