﻿using System;
using System.IO;
using System.Linq;
using Aquaforest.BarcodeReader.Api;
using Aquaforest.BarcodeReader.Common;

namespace GetOneBarcodePerPage
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                BarcodeReaderSettings settings = new BarcodeReaderSettings();

                // Barcode formats to look for
                settings.BarcodeFormats[BarcodeFormat.All_1D] = true;
                settings.BarcodeFormats[BarcodeFormat.AZTEC] = true;
                settings.BarcodeFormats[BarcodeFormat.DATA_MATRIX] = true;
                settings.BarcodeFormats[BarcodeFormat.MAXICODE] = true;
                settings.BarcodeFormats[BarcodeFormat.MSI] = true;
                settings.BarcodeFormats[BarcodeFormat.PDF_417] = true;
                settings.BarcodeFormats[BarcodeFormat.PLESSEY] = true;
                settings.BarcodeFormats[BarcodeFormat.QR_CODE] = true;
                settings.BarcodeFormats[BarcodeFormat.UPC_EAN_EXTENSION] = true;

                BarcodeReader reader = new BarcodeReader(settings);

                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

                string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
                if (!currentEnvironmentVariables.Contains(resourceFolder))
                {
                    Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                }
                reader.ResourceFolder = resourceFolder;

                reader.DecodeImage(Path.GetFullPath(@"..\..\..\..\documents\source\sample-barcodes.tif"));

                Console.WriteLine();
                Console.WriteLine("Decode Results");
                Console.WriteLine(new string('-', 30));

                foreach (var result in reader.DecodeResults.Where(r => r.Value.Success))
                {
                    BarcodeResult r = result.Value.BarcodeResult;

                    Console.WriteLine("Found barcode on page: {0}", result.Key); // or r.PageNumber
                    Console.WriteLine("Barcode Format: {0}", r.BarcodeFormat.ToString());
                    Console.WriteLine("Text: {0}", r.Text);
                    Console.WriteLine("Type: {0}", r.Type.ToString());
                    Console.WriteLine();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            }
        }
    }
}
