﻿using Aquaforest.ExtendedOCR.Api;
using Aquaforest.ExtendedOCR.Shared;
using System;
using System.IO;

namespace GetTextFromPage
{
	/*
	Note: This example will only get text from image-only pages. If a page already had text in it prior to the OCR, that text won’t be retrieved. 
	To extract text from image-only, partially searchable and fully searchable documents, check section 1.5 of the Cookbook or the following link:
	http://www.aquaforest.com/en/ocrsdk-extract-text-pdf.asp
	*/
	
    internal class Program
    {
        private static Ocr ocr;

        private static void Main(string[] args)
        {
            try
            {
                // Set OCR options
                ocr = new Ocr(@"..\..\..\..\..\xbin\resources");
                ocr.EnableConsoleOutput = true;
                ocr.Language = SupportedLanguages.English;
                ocr.StatusUpdate += OcrStatusUpdate;

                // Set PreProcessor options
                PreProcessor preProcessor = new PreProcessor();
                preProcessor.Deskew = true;
                preProcessor.Autorotate = false;

                // Read source TIFF file
                ocr.ReadTIFFSource(Path.GetFullPath(@"..\..\..\..\documents\source\sample.tif"));

                // Read source PDF file
                // ocr.ReadPDFSource(Path.GetFullPath(@"..\..\..\..\documents\source\image_pdf.pdf"));

                // Perform OCR recognition
                ocr.Recognize(preProcessor);

                ocr.DeleteTemporaryFiles();
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
            finally
            {
                if (ocr != null) ocr.Dispose();
            }
        }

        private static void OcrStatusUpdate(object sender, StatusUpdateEventArgs pageCompletedEventArgs)
        {
            Console.WriteLine("Page {0}:", pageCompletedEventArgs.PageNumber);

            if (pageCompletedEventArgs.TextAvailable)
            {
                Console.WriteLine(ocr.ReadPageString(pageCompletedEventArgs.PageNumber));
            }
            else
            {
                Console.WriteLine("No text found");
            }
        }
    }
}
