﻿using Aquaforest.ExtendedOCR.Api;
using System;

namespace IHQC_Compression
{
    class Program
    {
        private static void Main(string[] args)
        {
            try
            {
                using (Ocr ocr = new Ocr(@"..\..\..\..\..\xbin\resources"))
                {
                    // Set OCR options
                    ocr.EnableConsoleOutput = true;
                    ocr.EnableDebugOutput = true;
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnablePdfOutput = true;

                    // Set Intelligent High Quality Compression
                    ocr.IHQCCompression = new IHQCCompression
                    {
                        EnableIHQCCompression = true,
                        IHQCCompressionLevel = IHQCCompressionLevel.Level1,
                        IHQCQualityFactor = IHQCQualityFactor.Medium
                    };

                    // ExtractImageMethod must be set to ConvertToTiff for IHQC compression to work
                    // (only if the document being processed is a PDF file. This setting is not necessary if the source is an image file)
                    ocr.ExtractImageMethod = ExtractImageMethod.ConvertToTiff;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;

                    // Read source PDF file
                    ocr.ReadPDFSource(@"..\..\..\..\documents\source\compression_test.pdf");

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as compressed searchable PDF
                        ocr.SavePDFOutput(@"..\..\..\..\documents\output\compression_test.pdf", true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }
    }
}
