﻿using System;
using System.IO;
using Aquaforest.OCR.Api;

namespace MergeTIFFsToPDF
{
    class Program
    {
        static void Main(string[] args)
        {
            string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

            string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
            if (!currentEnvironmentVariables.Contains(resourceFolder))
            {
                Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
            }

            // Set PreProcessor options
            PreProcessor preProcessor = new PreProcessor();
            preProcessor.Deskew = true;
            preProcessor.RemoveLines = true;

            string sourcePath = @"..\..\..\..\documents\source";
            string outputPath = @"..\..\..\..\documents\output\pdfs_to_merge";

            if (!Directory.Exists(outputPath)) Directory.CreateDirectory(outputPath);

            // folder containing your tiff files
            DirectoryInfo dInfo = new DirectoryInfo(sourcePath);
            foreach (FileInfo f in dInfo.GetFiles("*.tif"))
            {
                Console.WriteLine("Processing file: {0}", f.FullName);

                using (Ocr ocr = new Ocr())
                {
                    // Set OCR options 
                    ocr.ResourceFolder = resourceFolder;
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnableConsoleOutput = true;
                    ocr.EnablePdfOutput = true;

                    // Read source TIFF file
                    ocr.ReadTIFFSource(f.FullName);

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(Path.Combine(outputPath, Path.ChangeExtension(f.Name, ".pdf")), true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }

            Console.WriteLine("Merging...");
            dInfo = new DirectoryInfo(outputPath);
            PdfMerger merger = new PdfMerger(@"..\..\..\..\documents\output\merge.pdf");

            foreach (FileInfo f in dInfo.GetFiles("*.pdf"))
            {
                merger.Append(f.FullName);
            }

            merger.Close();
            dInfo.Delete(true);
        }
    }
}



