﻿using Aquaforest.OCR.Api;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MultiThread
{
    class Program
    {
        private static string outputFolder = Path.GetFullPath(@"..\..\..\..\documents\output");
        private static string inputFolder = Path.GetFullPath(@"..\..\..\..\documents\source");
        private static int maxDegreeOfParallelism = 2;
        private static string resourceFolder;
        private static string tempPath;

        static void Main(string[] args)
        {
            tempPath = Path.Combine(Path.GetTempPath(), "MultiThread");
            resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin");

            string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");

            if (!currentEnvironmentVariables.Contains(resourceFolder))
            {
                Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
            }

            Parallel.ForEach(Directory.EnumerateFiles(inputFolder, "*.tif"), new ParallelOptions { MaxDegreeOfParallelism = maxDegreeOfParallelism }, f =>
            {
                var outputFilePath = Path.Combine(outputFolder, Path.GetFileNameWithoutExtension(f) + ".pdf");

                if (File.Exists(outputFilePath)) return;

                try
                {
                    ProcessDocument(f, outputFilePath);
                }
                catch (Exception e)
                {
                    Console.WriteLine("Error: " + e.Message);
                }
            });
        }

        static void ProcessDocument(string source, string output)
        {
            string tempFolder = Path.Combine(tempPath, Guid.NewGuid().ToString());

            try
            {
                using (Ocr ocr = new Ocr())
                {
                    ocr.ResourceFolder = resourceFolder;

                    // Set OCR options
                    ocr.TempFolder = tempFolder;
                    ocr.EnablePdfOutput = true;
                    ocr.Language = SupportedLanguages.English;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;

                    // Read source TIFF file
                    ocr.ReadTIFFSource(source);

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(output, true);

                        Console.WriteLine(source + " successfully processed.");
                    }
                    else
                    {
                        Console.WriteLine(source + " Failed");
                    }
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            }
            finally
            {
                if (Directory.Exists(tempFolder)) Directory.Delete(tempFolder, true);
            }
        }
    }
}