﻿using Aquaforest.ExtendedOCR.Api;
using System;
using System.IO;
using System.Threading.Tasks;

namespace MultiThreading
{
    class Program
    {
        private static string outputFolder = Path.GetFullPath(@"..\..\..\..\documents\output");
        private static string inputFolder = Path.GetFullPath(@"..\..\..\..\documents\source");
        private static int maxDegreeOfParallelism = 4;
        private static string resourceFolder;
        private static string tempPath;

        static void Main(string[] args)
        {
            tempPath = Path.Combine(Path.GetTempPath(), "MultiThread");
            resourceFolder = Path.GetFullPath(@"..\..\..\..\..\xbin\resources");

            Parallel.ForEach(Directory.EnumerateFiles(inputFolder, "*.tif"), new ParallelOptions { MaxDegreeOfParallelism = maxDegreeOfParallelism }, f =>
            {
                var outputFilePath = Path.Combine(outputFolder, Path.GetFileNameWithoutExtension(f) + ".pdf");
                if (File.Exists(outputFilePath)) return;

                try
                {
                    ProcessDocument(f, outputFilePath);
                }
                catch (Exception e)
                {
                    Console.WriteLine("ProcessDocument: " + e.Message);
                }
            });
        }

        public static void ProcessDocument(string source, string output)
        {
            string tempFolder = Path.Combine(tempPath, Guid.NewGuid().ToString());

            try
            {
                using (Ocr ocr = new Ocr(resourceFolder))
                {
                    // Set OCR options
                    ocr.TempFolder = tempFolder;
                    ocr.EnablePdfOutput = true;
                    ocr.Languages = new SupportedLanguages[]
                    {
                        SupportedLanguages.English,
                        SupportedLanguages.French,
                        SupportedLanguages.Spanish,
                        SupportedLanguages.German,
                    };

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;

                    // Read source PDF file
                    ocr.ReadTIFFSource(source);

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(output, true);
                    }
                    else
                    {
                        Console.WriteLine(source + " Failed");
                    }
                }
            }
            catch (Exception e)
            {
                Console.WriteLine(e.Message);
            }
            finally
            {
                if (Directory.Exists(tempFolder)) Directory.Delete(tempFolder, true);
            }
        }
    }
}
