﻿using Aquaforest.ExtendedOCR.Api;
using System;
using System.IO;

namespace MultipleLanguages
{
    internal class Program
    {
        private static void Main(string[] args)
        {
            try
            {
                string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\xbin\resources");

                using (Ocr ocr = new Ocr(resourceFolder))
                {
                    // Set OCR options
                    ocr.EnableConsoleOutput = true;
                    ocr.EnablePdfOutput = true;
                    ocr.Languages = new SupportedLanguages[]
                    {
                        SupportedLanguages.English,
                        SupportedLanguages.French,
                        SupportedLanguages.Spanish,
                        SupportedLanguages.German,
                        SupportedLanguages.Italian
                    };

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;
                    preProcessor.KeepOriginalImage = true;

                    // Read source TIFF file
                    ocr.ReadTIFFSource(@"..\..\..\..\documents\source\languages.tif");

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(@"..\..\..\..\documents\output\languages.pdf", true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }
    }
}