﻿using System;
using System.IO;
using Aquaforest.OCR.Api;

namespace OCRImagePDF
{
    class Program
    {
        static void Main(string[] args)
        {
            try
            {
                using (Ocr ocr = new Ocr())
                {
                    string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

                    string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
                    if (!currentEnvironmentVariables.Contains(resourceFolder))
                    {
                        Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                    }

                    // Set OCR options 
                    ocr.ResourceFolder = resourceFolder;
                    ocr.EnableConsoleOutput = true;
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnablePdfOutput = true;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;
                    preProcessor.Autorotate = false;

                    // Read source PDF file
                    ocr.ReadPDFSource(Path.GetFullPath(@"..\..\..\..\documents\source\image_pdf.pdf"));

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        ocr.SavePDFOutput(Path.GetFullPath(@"..\..\..\..\documents\output\searchable.pdf"), true);
                    }

                    ocr.DeleteTemporaryFiles();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }
    }
}
