﻿using System;
using System.IO;
using Aquaforest.OCR.Api;

namespace WordReader
{
    class ReadCharactersAfterAGivenString
    {
        static void Main(string[] args)
        {
            string result = "output";

            //Ocr the document and retrive the text as a string object
            string pageString = GetPageString(1, @"..\..\..\..\documents\source\invoice.tif");

            if (pageString != "failed")
            {
                // Get the Invoice Number
                if (pageString.Contains("Invoice Number: "))
                {
                    //Extract the next word(s) after "Invoice Number: " until the next new line character.
                    result = GetValueOfStringByKeyword(pageString, "Invoice Number: ", Environment.NewLine);
                    Console.WriteLine("Invoice Number : " + result);
                }

                // Get the Address 
                if (pageString.Contains("Address:"))
                {
                    //Extract the next word(s) after "Address:" until the next new line character
                    var result1 = GetValueOfStringByKeyword(pageString, "Address:", Environment.NewLine);
                    Console.WriteLine("Address: " + result1);
                }
            }
        }

        /// <param name="wordlist">The text of a the page</param>
        /// <param name="startString">Keyword, e.g. Name, Invoice No.</param>
        /// <param name="stopString">The string to stop at.</param>
        /// <returns>The value of the keyword (the text between the startString and the stopString)</returns>
        public static string GetValueOfStringByKeyword(string wordlist, string startString, string stopString)
        {
            var subset = wordlist.Substring(wordlist.IndexOf(startString));
            subset = ReplaceFirst(subset, startString, " ");
            var finalResult = subset.TrimStart();
            finalResult = finalResult.Substring(0, finalResult.IndexOf(stopString));

            if (finalResult == string.Empty)
            {
                return "Could not find the word: " + startString;
            }
            return finalResult;
        }

        public static string ReplaceFirst(string text, string search, string replace)
        {
            int pos = text.IndexOf(search);
            if (pos < 0)
            {
                return text;
            }
            return text.Substring(0, pos) + replace + text.Substring(pos + search.Length);
        }

        public static string GetPageString(int pageNumber, string inputFile)
        {
            string pageString = "";
            try
            {
                using (Ocr ocr = new Ocr())
                {
                    string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

                    string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
                    if (!currentEnvironmentVariables.Contains(resourceFolder))
                    {
                        Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                    }

                    // Set OCR options 
                    ocr.ResourceFolder = resourceFolder;
                    ocr.License = "";
                    ocr.EnableConsoleOutput = true;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;
                    preProcessor.Autorotate = false;
                    preProcessor.Binarize = -1;
                    preProcessor.Morph = "c2.2";

                    ocr.Language = SupportedLanguages.English;

                    if (Path.GetExtension(inputFile).ToLower() == ".tif")
                    {
                        // Read source TIFF file
                        ocr.ReadTIFFSource(Path.GetFullPath(inputFile));
                    }
                    else if (Path.GetExtension(inputFile).ToLower() == ".pdf")
                    {
                        // Read source PDF file
                        ocr.ReadPDFSource(Path.GetFullPath(inputFile));
                    }
                    else
                    {
                        return "failed";
                    }

                    // Perform OCR recognition
                    if (ocr.Recognize(preProcessor))
                    {
                        // Save output as searchable PDF
                        pageString = ocr.ReadPageString(pageNumber);
                    }
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
                pageString = "failed";
            }

            return pageString;
        }
    }
}
