﻿using System;
using System.IO;
using Aquaforest.OCR.Api;
using Aquaforest.OCR.Definitions;

namespace RecognitionToExcel
{
    class Program
    {
        static string csvOutputFilePath = @"..\..\..\..\documents\output\invoices.csv";

        static void Main(string[] args)
        {
            string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");

            string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");
            if (!currentEnvironmentVariables.Contains(resourceFolder))
            {
                Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
            }

            // Set PreProcessor options
            PreProcessor preProcessor = new PreProcessor();
            preProcessor.Deskew = true;
            preProcessor.RemoveLines = true;

            InitialiseExcel();

            DirectoryInfo dInfo = new DirectoryInfo(@"..\..\..\..\documents\source\invoices");

            foreach (FileInfo f in dInfo.GetFiles("*.tiff"))
            {
                using (Ocr ocr = new Ocr())
                {
                    // Set OCR options 
                    ocr.ResourceFolder = resourceFolder;
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnableConsoleOutput = true;

                    Console.WriteLine("Processing file: {0}", f.FullName);
                    ocr.ReadTIFFSource(f.FullName); // Read source TIFF file

                    // Perform OCR recognition
                    if (!ocr.Recognize(preProcessor)) continue;

                    bool[] skip = new bool[3];
                    ExcelRow row = new ExcelRow();

                    // Below is one method of getting text after a string or set of strings.
                    // Alternatively, you can use the method used in example 8 of the Aquaforest OCR SDK Cookbook - "Read Characters after a given string".
                    // The full Visual Studio project for that example can be found at '[SDK installation path]\samples\csharp\ReadCharactersAfterAGivenString'
                    Words words = ocr.ReadPageWords(1);

                    for (int i = 0; i < words.Count; i++)
                    {
                        if (!skip[0] && (words[i].Word == "Invoice" && (i + 1 < words.Count) && words[i + 1].Word == "Number:"))
                        {
                            if (i + 2 < words.Count)
                            {
                                row.InvoiceNumber = words[i + 2].Word;
                                i = i + 2;
                                skip[0] = true;
                                continue;
                            }
                        }

                        if (!skip[1] && (words[i].Word == "Invoice" && (i + 1 < words.Count) && words[i + 1].Word == "Date:"))
                        {
                            if (i + 2 < words.Count)
                            {
                                row.InvoiceDate = words[i + 2].Word;
                                i = i + 2;
                                skip[1] = true;
                                continue;
                            }
                        }

                        if (!skip[2] && (words[i].Word == "Customer" && (i + 1 < words.Count) && words[i + 1].Word == "Information:"))
                        {
                            int j = 2;

                            while (i + j < words.Count)
                            {
                                if (words[i + j].Word == "Billing")
                                {
                                    i = i + j;
                                    skip[2] = true;
                                    break;
                                }
                                else
                                {
                                    row.CustomerName += words[i + j].Word + " ";
                                }

                                j++;
                            }
                        }

                        if (skip[0] && skip[1] && skip[2])
                        {
                            break;
                        }
                    }

                    WriteRow(row);
                }
            }
        }

        static void InitialiseExcel()
        {
            File.WriteAllText(csvOutputFilePath, "Invoice Number,Invoice Date,Customer Name" + Environment.NewLine);
        }

        static void WriteRow(ExcelRow row)
        {
            string contents = string.Format("{0},{1},{2}{3}", row.InvoiceNumber, row.InvoiceDate, row.CustomerName, Environment.NewLine);

            Console.WriteLine(contents);
            File.AppendAllText(csvOutputFilePath, contents);
        }
    }

    class ExcelRow
    {
        public string InvoiceNumber { get; set; }
        public string InvoiceDate { get; set; }
        public string CustomerName { get; set; }
    }
}
