﻿using Aquaforest.ExtendedOCR.Api;
using Aquaforest.ExtendedOCR.Shared;
using System;
using System.IO;

namespace RecognitionToExcel
{
    internal class Program
    {
        private static string csvOutputFilePath = @"..\..\..\..\documents\output\invoices.csv";

        private static void Main(string[] args)
        {
            // Set PreProcessor options
            PreProcessor preProcessor = new PreProcessor();
            preProcessor.Deskew = true;

            InitialiseExcel();

            DirectoryInfo dInfo = new DirectoryInfo(@"..\..\..\..\documents\source\invoices");

            foreach (FileInfo f in dInfo.GetFiles("*.tiff"))
            {
                using (Ocr ocr = new Ocr(@"..\..\..\..\..\xbin\resources"))
                {
                    // Set OCR options
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnableConsoleOutput = true;

                    Console.WriteLine("Processing file: {0}", f.FullName);
                    ocr.ReadTIFFSource(f.FullName); // Read source TIFF file

                    if (!ocr.Recognize(preProcessor)) continue;

                    bool[] skip = new bool[2];
                    ExcelRow row = new ExcelRow();

                    Words words = ocr.ReadPageWords(1);

                    for (int i = 0; i < words.Count; i++)
                    {
                        if (!skip[0] && (words[i].Word == "Invoice" && (i + 1 < words.Count) && words[i + 1].Word == "Number:"))
                        {
                            if (i + 2 < words.Count)
                            {
                                row.InvoiceNumber = words[i + 2].Word;
                                i = i + 2;
                                skip[0] = true;
                                continue;
                            }
                        }

                        if (!skip[1] && (words[i].Word == "Invoice" && (i + 1 < words.Count) && words[i + 1].Word == "Date:"))
                        {
                            if (i + 2 < words.Count)
                            {
                                row.InvoiceDate = words[i + 2].Word;
                                i = i + 2;
                                skip[1] = true;
                                continue;
                            }
                        }

                        if (skip[0] && skip[1])
                        {
                            break;
                        }
                    }

                    WriteRow(row);
                }
            }
        }

        private static void InitialiseExcel()
        {
            File.WriteAllText(csvOutputFilePath, "Invoice Number,Invoice Date" + Environment.NewLine);
        }

        private static void WriteRow(ExcelRow row)
        {
            string contents = string.Format("{0},{1}{2}", row.InvoiceNumber, row.InvoiceDate, Environment.NewLine);

            Console.WriteLine(contents);
            File.AppendAllText(csvOutputFilePath, contents);
        }
    }

    internal class ExcelRow
    {
        public string InvoiceNumber { get; set; }
        public string InvoiceDate { get; set; }
    }
}