﻿using System;
using System.Drawing;
using System.IO;
using Aquaforest.OCR.Api;

namespace ocr
{
    class ZonesWithDifferentOrientations
    {
        static void Main(string[] args)
        {
            try
            {
                using (var img = Image.FromFile(@"..\..\..\..\documents\source\different_text_orientations.tif", true))
                using (var bmp = new Bitmap(img))
                {
                    // Variables for the coordinates
                    int x, y, height, width;

                    // First example - United State Patent block. Assign values for the coordinates of the area you wish to convert
                    x = 320; y = 110; height = 200; width = 690;

                    // Crop the image
                    using (Bitmap croppedBmp = bmp.Clone(new Rectangle(x, y, width, height), img.PixelFormat))
                    {
                        croppedBmp.SetResolution(img.HorizontalResolution, img.VerticalResolution);

                        string zoneText = GetZoneText(croppedBmp, false);
                        Console.WriteLine("Zone 1: " + Environment.NewLine + zoneText);
                    }

                    // Second example - Inventor Details block. Assign values for the coordinates of the area you wish to convert
                    x = 65; y = 465; height = 650; width = 160;

                    //Crop the image
                    using (var croppedBmp = bmp.Clone(new Rectangle(x, y, width, height), bmp.PixelFormat))
                    {
                        croppedBmp.SetResolution(img.HorizontalResolution, img.VerticalResolution);

                        // Set autorotate = true so that the text will be read in the correct orientation.
                        string zoneText = GetZoneText(croppedBmp, true);
                        Console.WriteLine("Zone 2: " + Environment.NewLine + zoneText);
                    }
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("Error in OCR Processing :" + e.Message);
            }
        }

        static string GetZoneText(Bitmap bmp, bool autorotate)
        {
            using (Ocr ocr = new Ocr())
            {
                string ocredText = "";

                try
                {
                    string resourceFolder = Path.GetFullPath(@"..\..\..\..\..\bin\");
                    string currentEnvironmentVariables = Environment.GetEnvironmentVariable("PATH");

                    if (!currentEnvironmentVariables.Contains(resourceFolder))
                    {
                        Environment.SetEnvironmentVariable("PATH", currentEnvironmentVariables + ";" + resourceFolder);
                    }

                    // Set OCR options
                    ocr.ResourceFolder = resourceFolder;
                    ocr.Language = SupportedLanguages.English;
                    ocr.EnableConsoleOutput = true;

                    // Set PreProcessor options
                    PreProcessor preProcessor = new PreProcessor();
                    preProcessor.Deskew = true;
                    preProcessor.Autorotate = autorotate;

                    ocr.ReadImageSource(bmp);

                    if (ocr.Recognize(preProcessor))
                    {
                        ocredText = ocr.ReadPageString(1);
                    }
                }
                catch (Exception e)
                {
                    Console.WriteLine("Error in OCR Processing :" + e.Message);
                }
                finally
                {
                    ocr.DeleteTemporaryFiles();
                }

                return ocredText;
            }
        }
    }
}